# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tk8s.proto\x12\x1copi_api.network.k8s.v1alpha1Be\n\x1copi_api.network.k8s.v1alpha1B\x08K8sProtoP\x01Z9github.com/opiproject/opi-api/network/k8s/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'k8s_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034opi_api.network.k8s.v1alpha1B\010K8sProtoP\001Z9github.com/opiproject/opi-api/network/k8s/v1alpha1/gen/go'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: component.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63omponent.proto\x12 opi_api.network.evpn_gw.v1alpha1\x1a\x1fgoogle/api/field_behavior.proto\"\x91\x01\n\tComponent\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12J\n\x06status\x18\x02 \x01(\x0e\x32,.opi_api.network.evpn_gw.v1alpha1.CompStatusB\x04\xe2\x41\x01\x03R\x06status\x12\x1e\n\x07\x64\x65tails\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x64\x65tails*r\n\nCompStatus\x12\x1b\n\x17\x43OMP_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43OMP_STATUS_PENDING\x10\x01\x12\x17\n\x13\x43OMP_STATUS_SUCCESS\x10\x02\x12\x15\n\x11\x43OMP_STATUS_ERROR\x10\x03\x42s\n opi_api.network.evpn_gw.v1alpha1B\x0e\x43omponentProtoP\x01Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'component_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n opi_api.network.evpn_gw.v1alpha1B\016ComponentProtoP\001Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/go'
  _globals['_COMPONENT'].fields_by_name['name']._options = None
  _globals['_COMPONENT'].fields_by_name['name']._serialized_options = b'\342A\001\003'
  _globals['_COMPONENT'].fields_by_name['status']._options = None
  _globals['_COMPONENT'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_COMPONENT'].fields_by_name['details']._options = None
  _globals['_COMPONENT'].fields_by_name['details']._serialized_options = b'\342A\001\003'
  _globals['_COMPSTATUS']._serialized_start=234
  _globals['_COMPSTATUS']._serialized_end=348
  _globals['_COMPONENT']._serialized_start=87
  _globals['_COMPONENT']._serialized_end=232
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: l3_xpu_infra_mgr.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
import component_pb2 as component__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16l3_xpu_infra_mgr.proto\x12 opi_api.network.evpn_gw.v1alpha1\x1a\x12networktypes.proto\x1a\x0f\x63omponent.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x19google/api/resource.proto\"\xf1\x01\n\x03Vrf\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x43\n\x04spec\x18\x02 \x01(\x0b\x32).opi_api.network.evpn_gw.v1alpha1.VrfSpecB\x04\xe2\x41\x01\x02R\x04spec\x12I\n\x06status\x18\x03 \x01(\x0b\x32+.opi_api.network.evpn_gw.v1alpha1.VrfStatusB\x04\xe2\x41\x01\x03R\x06status:@\xea\x41=\n$opi_api.network.evpn_gw.v1alpha1/Vrf\x12\nvrfs/{vrf}*\x04vrfs2\x03vrf\"\xf0\x01\n\x07VrfSpec\x12\x1b\n\x03vni\x18\x01 \x01(\rB\x04\xe2\x41\x01\x01H\x00R\x03vni\x88\x01\x01\x12\x63\n\x12loopback_ip_prefix\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixB\x04\xe2\x41\x01\x02R\x10loopbackIpPrefix\x12[\n\x0evtep_ip_prefix\x18\x03 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixB\x04\xe2\x41\x01\x01R\x0cvtepIpPrefixB\x06\n\x04_vni\"\xb6\x01\n\tVrfStatus\x12V\n\x0boper_status\x18\x08 \x01(\x0e\x32/.opi_api.network.evpn_gw.v1alpha1.VRFOperStatusB\x04\xe2\x41\x01\x03R\noperStatus\x12Q\n\ncomponents\x18\t \x03(\x0b\x32+.opi_api.network.evpn_gw.v1alpha1.ComponentB\x04\xe2\x41\x01\x03R\ncomponents\"n\n\x10\x43reateVrfRequest\x12\x1b\n\x06vrf_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01R\x05vrfId\x12=\n\x03vrf\x18\x02 \x01(\x0b\x32%.opi_api.network.evpn_gw.v1alpha1.VrfB\x04\xe2\x41\x01\x02R\x03vrf\"Y\n\x0fListVrfsRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"u\n\x10ListVrfsResponse\x12\x39\n\x04vrfs\x18\x01 \x03(\x0b\x32%.opi_api.network.evpn_gw.v1alpha1.VrfR\x04vrfs\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\rGetVrfRequest\x12\x41\n\x04name\x18\x01 \x01(\tB-\xe2\x41\x01\x02\xfa\x41&\n$opi_api.network.evpn_gw.v1alpha1/VrfR\x04name\"\x80\x01\n\x10\x44\x65leteVrfRequest\x12\x41\n\x04name\x18\x01 \x01(\tB-\xe2\x41\x01\x02\xfa\x41&\n$opi_api.network.evpn_gw.v1alpha1/VrfR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xbf\x01\n\x10UpdateVrfRequest\x12=\n\x03vrf\x18\x01 \x01(\x0b\x32%.opi_api.network.evpn_gw.v1alpha1.VrfB\x04\xe2\x41\x01\x02R\x03vrf\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xf1\x01\n\x03Svi\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x43\n\x04spec\x18\x02 \x01(\x0b\x32).opi_api.network.evpn_gw.v1alpha1.SviSpecB\x04\xe2\x41\x01\x02R\x04spec\x12I\n\x06status\x18\x03 \x01(\x0b\x32+.opi_api.network.evpn_gw.v1alpha1.SviStatusB\x04\xe2\x41\x01\x03R\x06status:@\xea\x41=\n$opi_api.network.evpn_gw.v1alpha1/Svi\x12\nsvis/{svi}*\x04svis2\x03svi\"\xf2\x02\n\x07SviSpec\x12?\n\x03vrf\x18\x01 \x01(\tB-\xe2\x41\x01\x02\xfa\x41&\n$opi_api.network.evpn_gw.v1alpha1/VrfR\x03vrf\x12^\n\x0elogical_bridge\x18\x02 \x01(\tB7\xe2\x41\x01\x02\xfa\x41\x30\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridgeR\rlogicalBridge\x12%\n\x0bmac_address\x18\x03 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\nmacAddress\x12W\n\x0cgw_ip_prefix\x18\x04 \x03(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixB\x04\xe2\x41\x01\x02R\ngwIpPrefix\x12#\n\nenable_bgp\x18\x05 \x01(\x08\x42\x04\xe2\x41\x01\x01R\tenableBgp\x12!\n\tremote_as\x18\x06 \x01(\rB\x04\xe2\x41\x01\x01R\x08remoteAs\"\xb6\x01\n\tSviStatus\x12V\n\x0boper_status\x18\x01 \x01(\x0e\x32/.opi_api.network.evpn_gw.v1alpha1.SVIOperStatusB\x04\xe2\x41\x01\x03R\noperStatus\x12Q\n\ncomponents\x18\x02 \x03(\x0b\x32+.opi_api.network.evpn_gw.v1alpha1.ComponentB\x04\xe2\x41\x01\x03R\ncomponents\"n\n\x10\x43reateSviRequest\x12\x1b\n\x06svi_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x01R\x05sviId\x12=\n\x03svi\x18\x02 \x01(\x0b\x32%.opi_api.network.evpn_gw.v1alpha1.SviB\x04\xe2\x41\x01\x02R\x03svi\"Y\n\x0fListSvisRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"u\n\x10ListSvisResponse\x12\x39\n\x04svis\x18\x01 \x03(\x0b\x32%.opi_api.network.evpn_gw.v1alpha1.SviR\x04svis\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"R\n\rGetSviRequest\x12\x41\n\x04name\x18\x01 \x01(\tB-\xe2\x41\x01\x02\xfa\x41&\n$opi_api.network.evpn_gw.v1alpha1/SviR\x04name\"\x80\x01\n\x10\x44\x65leteSviRequest\x12\x41\n\x04name\x18\x01 \x01(\tB-\xe2\x41\x01\x02\xfa\x41&\n$opi_api.network.evpn_gw.v1alpha1/SviR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xbf\x01\n\x10UpdateSviRequest\x12=\n\x03svi\x18\x01 \x01(\x0b\x32%.opi_api.network.evpn_gw.v1alpha1.SviB\x04\xe2\x41\x01\x02R\x03svi\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing*\x85\x01\n\rVRFOperStatus\x12\x1f\n\x1bVRF_OPER_STATUS_UNSPECIFIED\x10\x00\x12\x16\n\x12VRF_OPER_STATUS_UP\x10\x01\x12\x18\n\x14VRF_OPER_STATUS_DOWN\x10\x02\x12!\n\x1dVRF_OPER_STATUS_TO_BE_DELETED\x10\x03*\x85\x01\n\rSVIOperStatus\x12\x1f\n\x1bSVI_OPER_STATUS_UNSPECIFIED\x10\x00\x12\x16\n\x12SVI_OPER_STATUS_UP\x10\x01\x12\x18\n\x14SVI_OPER_STATUS_DOWN\x10\x02\x12!\n\x1dSVI_OPER_STATUS_TO_BE_DELETED\x10\x03\x32\xbe\x05\n\nVrfService\x12\x8a\x01\n\tCreateVrf\x12\x32.opi_api.network.evpn_gw.v1alpha1.CreateVrfRequest\x1a%.opi_api.network.evpn_gw.v1alpha1.Vrf\"\"\xda\x41\nvrf,vrf_id\x82\xd3\xe4\x93\x02\x0f\"\x08/v1/vrfs:\x03vrf\x12\x83\x01\n\x08ListVrfs\x12\x31.opi_api.network.evpn_gw.v1alpha1.ListVrfsRequest\x1a\x32.opi_api.network.evpn_gw.v1alpha1.ListVrfsResponse\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/vrfs\x12\x82\x01\n\x06GetVrf\x12/.opi_api.network.evpn_gw.v1alpha1.GetVrfRequest\x1a%.opi_api.network.evpn_gw.v1alpha1.Vrf\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/{name=vrfs/*}\x12y\n\tDeleteVrf\x12\x32.opi_api.network.evpn_gw.v1alpha1.DeleteVrfRequest\x1a\x16.google.protobuf.Empty\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13*\x11/v1/{name=vrfs/*}\x12\x9c\x01\n\tUpdateVrf\x12\x32.opi_api.network.evpn_gw.v1alpha1.UpdateVrfRequest\x1a%.opi_api.network.evpn_gw.v1alpha1.Vrf\"4\xda\x41\x0fvrf,update_mask\x82\xd3\xe4\x93\x02\x1c\x32\x15/v1/{vrf.name=vrfs/*}:\x03vrf2\xbe\x05\n\nSviService\x12\x8a\x01\n\tCreateSvi\x12\x32.opi_api.network.evpn_gw.v1alpha1.CreateSviRequest\x1a%.opi_api.network.evpn_gw.v1alpha1.Svi\"\"\xda\x41\nsvi,svi_id\x82\xd3\xe4\x93\x02\x0f\"\x08/v1/svis:\x03svi\x12\x83\x01\n\x08ListSvis\x12\x31.opi_api.network.evpn_gw.v1alpha1.ListSvisRequest\x1a\x32.opi_api.network.evpn_gw.v1alpha1.ListSvisResponse\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/svis\x12\x82\x01\n\x06GetSvi\x12/.opi_api.network.evpn_gw.v1alpha1.GetSviRequest\x1a%.opi_api.network.evpn_gw.v1alpha1.Svi\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/{name=svis/*}\x12y\n\tDeleteSvi\x12\x32.opi_api.network.evpn_gw.v1alpha1.DeleteSviRequest\x1a\x16.google.protobuf.Empty\" \xda\x41\x04name\x82\xd3\xe4\x93\x02\x13*\x11/v1/{name=svis/*}\x12\x9c\x01\n\tUpdateSvi\x12\x32.opi_api.network.evpn_gw.v1alpha1.UpdateSviRequest\x1a%.opi_api.network.evpn_gw.v1alpha1.Svi\"4\xda\x41\x0fsvi,update_mask\x82\xd3\xe4\x93\x02\x1c\x32\x15/v1/{svi.name=svis/*}:\x03sviBw\n opi_api.network.evpn_gw.v1alpha1B\x12L3XpuInfraMgrProtoP\x01Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'l3_xpu_infra_mgr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n opi_api.network.evpn_gw.v1alpha1B\022L3XpuInfraMgrProtoP\001Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/go'
  _globals['_VRF'].fields_by_name['name']._options = None
  _globals['_VRF'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VRF'].fields_by_name['spec']._options = None
  _globals['_VRF'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_VRF'].fields_by_name['status']._options = None
  _globals['_VRF'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_VRF']._options = None
  _globals['_VRF']._serialized_options = b'\352A=\n$opi_api.network.evpn_gw.v1alpha1/Vrf\022\nvrfs/{vrf}*\004vrfs2\003vrf'
  _globals['_VRFSPEC'].fields_by_name['vni']._options = None
  _globals['_VRFSPEC'].fields_by_name['vni']._serialized_options = b'\342A\001\001'
  _globals['_VRFSPEC'].fields_by_name['loopback_ip_prefix']._options = None
  _globals['_VRFSPEC'].fields_by_name['loopback_ip_prefix']._serialized_options = b'\342A\001\002'
  _globals['_VRFSPEC'].fields_by_name['vtep_ip_prefix']._options = None
  _globals['_VRFSPEC'].fields_by_name['vtep_ip_prefix']._serialized_options = b'\342A\001\001'
  _globals['_VRFSTATUS'].fields_by_name['oper_status']._options = None
  _globals['_VRFSTATUS'].fields_by_name['oper_status']._serialized_options = b'\342A\001\003'
  _globals['_VRFSTATUS'].fields_by_name['components']._options = None
  _globals['_VRFSTATUS'].fields_by_name['components']._serialized_options = b'\342A\001\003'
  _globals['_CREATEVRFREQUEST'].fields_by_name['vrf_id']._options = None
  _globals['_CREATEVRFREQUEST'].fields_by_name['vrf_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEVRFREQUEST'].fields_by_name['vrf']._options = None
  _globals['_CREATEVRFREQUEST'].fields_by_name['vrf']._serialized_options = b'\342A\001\002'
  _globals['_LISTVRFSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVRFSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVRFSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVRFSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVRFREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVRFREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A&\n$opi_api.network.evpn_gw.v1alpha1/Vrf'
  _globals['_DELETEVRFREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVRFREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A&\n$opi_api.network.evpn_gw.v1alpha1/Vrf'
  _globals['_DELETEVRFREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVRFREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['vrf']._options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['vrf']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVRFREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVRFREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_SVI'].fields_by_name['name']._options = None
  _globals['_SVI'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_SVI'].fields_by_name['spec']._options = None
  _globals['_SVI'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_SVI'].fields_by_name['status']._options = None
  _globals['_SVI'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_SVI']._options = None
  _globals['_SVI']._serialized_options = b'\352A=\n$opi_api.network.evpn_gw.v1alpha1/Svi\022\nsvis/{svi}*\004svis2\003svi'
  _globals['_SVISPEC'].fields_by_name['vrf']._options = None
  _globals['_SVISPEC'].fields_by_name['vrf']._serialized_options = b'\342A\001\002\372A&\n$opi_api.network.evpn_gw.v1alpha1/Vrf'
  _globals['_SVISPEC'].fields_by_name['logical_bridge']._options = None
  _globals['_SVISPEC'].fields_by_name['logical_bridge']._serialized_options = b'\342A\001\002\372A0\n.opi_api.network.evpn_gw.v1alpha1/LogicalBridge'
  _globals['_SVISPEC'].fields_by_name['mac_address']._options = None
  _globals['_SVISPEC'].fields_by_name['mac_address']._serialized_options = b'\342A\001\002'
  _globals['_SVISPEC'].fields_by_name['gw_ip_prefix']._options = None
  _globals['_SVISPEC'].fields_by_name['gw_ip_prefix']._serialized_options = b'\342A\001\002'
  _globals['_SVISPEC'].fields_by_name['enable_bgp']._options = None
  _globals['_SVISPEC'].fields_by_name['enable_bgp']._serialized_options = b'\342A\001\001'
  _globals['_SVISPEC'].fields_by_name['remote_as']._options = None
  _globals['_SVISPEC'].fields_by_name['remote_as']._serialized_options = b'\342A\001\001'
  _globals['_SVISTATUS'].fields_by_name['oper_status']._options = None
  _globals['_SVISTATUS'].fields_by_name['oper_status']._serialized_options = b'\342A\001\003'
  _globals['_SVISTATUS'].fields_by_name['components']._options = None
  _globals['_SVISTATUS'].fields_by_name['components']._serialized_options = b'\342A\001\003'
  _globals['_CREATESVIREQUEST'].fields_by_name['svi_id']._options = None
  _globals['_CREATESVIREQUEST'].fields_by_name['svi_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATESVIREQUEST'].fields_by_name['svi']._options = None
  _globals['_CREATESVIREQUEST'].fields_by_name['svi']._serialized_options = b'\342A\001\002'
  _globals['_LISTSVISREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTSVISREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTSVISREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTSVISREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETSVIREQUEST'].fields_by_name['name']._options = None
  _globals['_GETSVIREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A&\n$opi_api.network.evpn_gw.v1alpha1/Svi'
  _globals['_DELETESVIREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETESVIREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A&\n$opi_api.network.evpn_gw.v1alpha1/Svi'
  _globals['_DELETESVIREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETESVIREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATESVIREQUEST'].fields_by_name['svi']._options = None
  _globals['_UPDATESVIREQUEST'].fields_by_name['svi']._serialized_options = b'\342A\001\002'
  _globals['_UPDATESVIREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATESVIREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATESVIREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATESVIREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_VRFSERVICE'].methods_by_name['CreateVrf']._options = None
  _globals['_VRFSERVICE'].methods_by_name['CreateVrf']._serialized_options = b'\332A\nvrf,vrf_id\202\323\344\223\002\017\"\010/v1/vrfs:\003vrf'
  _globals['_VRFSERVICE'].methods_by_name['ListVrfs']._options = None
  _globals['_VRFSERVICE'].methods_by_name['ListVrfs']._serialized_options = b'\202\323\344\223\002\n\022\010/v1/vrfs'
  _globals['_VRFSERVICE'].methods_by_name['GetVrf']._options = None
  _globals['_VRFSERVICE'].methods_by_name['GetVrf']._serialized_options = b'\332A\004name\202\323\344\223\002\023\022\021/v1/{name=vrfs/*}'
  _globals['_VRFSERVICE'].methods_by_name['DeleteVrf']._options = None
  _globals['_VRFSERVICE'].methods_by_name['DeleteVrf']._serialized_options = b'\332A\004name\202\323\344\223\002\023*\021/v1/{name=vrfs/*}'
  _globals['_VRFSERVICE'].methods_by_name['UpdateVrf']._options = None
  _globals['_VRFSERVICE'].methods_by_name['UpdateVrf']._serialized_options = b'\332A\017vrf,update_mask\202\323\344\223\002\0342\025/v1/{vrf.name=vrfs/*}:\003vrf'
  _globals['_SVISERVICE'].methods_by_name['CreateSvi']._options = None
  _globals['_SVISERVICE'].methods_by_name['CreateSvi']._serialized_options = b'\332A\nsvi,svi_id\202\323\344\223\002\017\"\010/v1/svis:\003svi'
  _globals['_SVISERVICE'].methods_by_name['ListSvis']._options = None
  _globals['_SVISERVICE'].methods_by_name['ListSvis']._serialized_options = b'\202\323\344\223\002\n\022\010/v1/svis'
  _globals['_SVISERVICE'].methods_by_name['GetSvi']._options = None
  _globals['_SVISERVICE'].methods_by_name['GetSvi']._serialized_options = b'\332A\004name\202\323\344\223\002\023\022\021/v1/{name=svis/*}'
  _globals['_SVISERVICE'].methods_by_name['DeleteSvi']._options = None
  _globals['_SVISERVICE'].methods_by_name['DeleteSvi']._serialized_options = b'\332A\004name\202\323\344\223\002\023*\021/v1/{name=svis/*}'
  _globals['_SVISERVICE'].methods_by_name['UpdateSvi']._options = None
  _globals['_SVISERVICE'].methods_by_name['UpdateSvi']._serialized_options = b'\332A\017svi,update_mask\202\323\344\223\002\0342\025/v1/{svi.name=svis/*}:\003svi'
  _globals['_VRFOPERSTATUS']._serialized_start=3212
  _globals['_VRFOPERSTATUS']._serialized_end=3345
  _globals['_SVIOPERSTATUS']._serialized_start=3348
  _globals['_SVIOPERSTATUS']._serialized_end=3481
  _globals['_VRF']._serialized_start=276
  _globals['_VRF']._serialized_end=517
  _globals['_VRFSPEC']._serialized_start=520
  _globals['_VRFSPEC']._serialized_end=760
  _globals['_VRFSTATUS']._serialized_start=763
  _globals['_VRFSTATUS']._serialized_end=945
  _globals['_CREATEVRFREQUEST']._serialized_start=947
  _globals['_CREATEVRFREQUEST']._serialized_end=1057
  _globals['_LISTVRFSREQUEST']._serialized_start=1059
  _globals['_LISTVRFSREQUEST']._serialized_end=1148
  _globals['_LISTVRFSRESPONSE']._serialized_start=1150
  _globals['_LISTVRFSRESPONSE']._serialized_end=1267
  _globals['_GETVRFREQUEST']._serialized_start=1269
  _globals['_GETVRFREQUEST']._serialized_end=1351
  _globals['_DELETEVRFREQUEST']._serialized_start=1354
  _globals['_DELETEVRFREQUEST']._serialized_end=1482
  _globals['_UPDATEVRFREQUEST']._serialized_start=1485
  _globals['_UPDATEVRFREQUEST']._serialized_end=1676
  _globals['_SVI']._serialized_start=1679
  _globals['_SVI']._serialized_end=1920
  _globals['_SVISPEC']._serialized_start=1923
  _globals['_SVISPEC']._serialized_end=2293
  _globals['_SVISTATUS']._serialized_start=2296
  _globals['_SVISTATUS']._serialized_end=2478
  _globals['_CREATESVIREQUEST']._serialized_start=2480
  _globals['_CREATESVIREQUEST']._serialized_end=2590
  _globals['_LISTSVISREQUEST']._serialized_start=2592
  _globals['_LISTSVISREQUEST']._serialized_end=2681
  _globals['_LISTSVISRESPONSE']._serialized_start=2683
  _globals['_LISTSVISRESPONSE']._serialized_end=2800
  _globals['_GETSVIREQUEST']._serialized_start=2802
  _globals['_GETSVIREQUEST']._serialized_end=2884
  _globals['_DELETESVIREQUEST']._serialized_start=2887
  _globals['_DELETESVIREQUEST']._serialized_end=3015
  _globals['_UPDATESVIREQUEST']._serialized_start=3018
  _globals['_UPDATESVIREQUEST']._serialized_end=3209
  _globals['_VRFSERVICE']._serialized_start=3484
  _globals['_VRFSERVICE']._serialized_end=4186
  _globals['_SVISERVICE']._serialized_start=4189
  _globals['_SVISERVICE']._serialized_end=4891
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_virtio_blk.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x66rontend_virtio_blk.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\x88\x03\n\tVirtioBlk\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12>\n\x07pcie_id\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpointB\x04\xe2\x41\x01\x02R\x06pcieId\x12,\n\x0fvolume_name_ref\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef\x12\"\n\nmax_io_qps\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x08maxIoQps\x12?\n\tmin_limit\x18\x05 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08minLimit\x12?\n\tmax_limit\x18\x06 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08maxLimit:M\xea\x41J\n\x1copi_api.storage.v1/VirtioBlk\x12\x13virtioBlks/{volume}*\nvirtioBlks2\tvirtioBlk\"\x86\x01\n\x16\x43reateVirtioBlkRequest\x12\x42\n\nvirtio_blk\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.VirtioBlkB\x04\xe2\x41\x01\x02R\tvirtioBlk\x12(\n\rvirtio_blk_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0bvirtioBlkId\"~\n\x16\x44\x65leteVirtioBlkRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlkR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xca\x01\n\x16UpdateVirtioBlkRequest\x12\x42\n\nvirtio_blk\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.VirtioBlkB\x04\xe2\x41\x01\x02R\tvirtioBlk\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"_\n\x15ListVirtioBlksRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x80\x01\n\x16ListVirtioBlksResponse\x12>\n\x0bvirtio_blks\x18\x01 \x03(\x0b\x32\x1d.opi_api.storage.v1.VirtioBlkR\nvirtioBlks\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x13GetVirtioBlkRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlkR\x04name\"R\n\x15StatsVirtioBlkRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/VirtioBlkR\x04name\"O\n\x16StatsVirtioBlkResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\x80\x07\n\x18\x46rontendVirtioBlkService\x12\x9b\x01\n\x0f\x43reateVirtioBlk\x12*.opi_api.storage.v1.CreateVirtioBlkRequest\x1a\x1d.opi_api.storage.v1.VirtioBlk\"=\xda\x41\x18virtio_blk,virtio_blk_id\x82\xd3\xe4\x93\x02\x1c\"\x0e/v1/virtioBlks:\nvirtio_blk\x12}\n\x0f\x44\x65leteVirtioBlk\x12*.opi_api.storage.v1.DeleteVirtioBlkRequest\x1a\x16.google.protobuf.Empty\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19*\x17/v1/{name=virtioBlks/*}\x12\xad\x01\n\x0fUpdateVirtioBlk\x12*.opi_api.storage.v1.UpdateVirtioBlkRequest\x1a\x1d.opi_api.storage.v1.VirtioBlk\"O\xda\x41\x16virtio_blk,update_mask\x82\xd3\xe4\x93\x02\x30\x32\"/v1/{virtio_blk.name=virtioBlks/*}:\nvirtio_blk\x12\x7f\n\x0eListVirtioBlks\x12).opi_api.storage.v1.ListVirtioBlksRequest\x1a*.opi_api.storage.v1.ListVirtioBlksResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/virtioBlks\x12~\n\x0cGetVirtioBlk\x12\'.opi_api.storage.v1.GetVirtioBlkRequest\x1a\x1d.opi_api.storage.v1.VirtioBlk\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{name=virtioBlks/*}\x12\x95\x01\n\x0eStatsVirtioBlk\x12).opi_api.storage.v1.StatsVirtioBlkRequest\x1a*.opi_api.storage.v1.StatsVirtioBlkResponse\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=virtioBlks/*}:statsBe\n\x12opi_api.storage.v1B\x16\x46rontendVirtioBlkProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'frontend_virtio_blk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\026FrontendVirtioBlkProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_VIRTIOBLK'].fields_by_name['name']._options = None
  _globals['_VIRTIOBLK'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOBLK'].fields_by_name['pcie_id']._options = None
  _globals['_VIRTIOBLK'].fields_by_name['pcie_id']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOBLK'].fields_by_name['volume_name_ref']._options = None
  _globals['_VIRTIOBLK'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOBLK'].fields_by_name['max_io_qps']._options = None
  _globals['_VIRTIOBLK'].fields_by_name['max_io_qps']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOBLK'].fields_by_name['min_limit']._options = None
  _globals['_VIRTIOBLK'].fields_by_name['min_limit']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOBLK'].fields_by_name['max_limit']._options = None
  _globals['_VIRTIOBLK'].fields_by_name['max_limit']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOBLK']._options = None
  _globals['_VIRTIOBLK']._serialized_options = b'\352AJ\n\034opi_api.storage.v1/VirtioBlk\022\023virtioBlks/{volume}*\nvirtioBlks2\tvirtioBlk'
  _globals['_CREATEVIRTIOBLKREQUEST'].fields_by_name['virtio_blk']._options = None
  _globals['_CREATEVIRTIOBLKREQUEST'].fields_by_name['virtio_blk']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOBLKREQUEST'].fields_by_name['virtio_blk_id']._options = None
  _globals['_CREATEVIRTIOBLKREQUEST'].fields_by_name['virtio_blk_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOBLKREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOBLKREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _globals['_DELETEVIRTIOBLKREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOBLKREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOBLKREQUEST'].fields_by_name['virtio_blk']._options = None
  _globals['_UPDATEVIRTIOBLKREQUEST'].fields_by_name['virtio_blk']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOBLKREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOBLKREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOBLKREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOBLKREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOBLKSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOBLKSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOBLKSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOBLKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOBLKREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOBLKREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _globals['_STATSVIRTIOBLKREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOBLKREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/VirtioBlk'
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['CreateVirtioBlk']._options = None
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['CreateVirtioBlk']._serialized_options = b'\332A\030virtio_blk,virtio_blk_id\202\323\344\223\002\034\"\016/v1/virtioBlks:\nvirtio_blk'
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['DeleteVirtioBlk']._options = None
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['DeleteVirtioBlk']._serialized_options = b'\332A\004name\202\323\344\223\002\031*\027/v1/{name=virtioBlks/*}'
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['UpdateVirtioBlk']._options = None
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['UpdateVirtioBlk']._serialized_options = b'\332A\026virtio_blk,update_mask\202\323\344\223\00202\"/v1/{virtio_blk.name=virtioBlks/*}:\nvirtio_blk'
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['ListVirtioBlks']._options = None
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['ListVirtioBlks']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/virtioBlks'
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['GetVirtioBlk']._options = None
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['GetVirtioBlk']._serialized_options = b'\332A\004name\202\323\344\223\002\031\022\027/v1/{name=virtioBlks/*}'
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['StatsVirtioBlk']._options = None
  _globals['_FRONTENDVIRTIOBLKSERVICE'].methods_by_name['StatsVirtioBlk']._serialized_options = b'\332A\004name\202\323\344\223\002\037\022\035/v1/{name=virtioBlks/*}:stats'
  _globals['_VIRTIOBLK']._serialized_start=245
  _globals['_VIRTIOBLK']._serialized_end=637
  _globals['_CREATEVIRTIOBLKREQUEST']._serialized_start=640
  _globals['_CREATEVIRTIOBLKREQUEST']._serialized_end=774
  _globals['_DELETEVIRTIOBLKREQUEST']._serialized_start=776
  _globals['_DELETEVIRTIOBLKREQUEST']._serialized_end=902
  _globals['_UPDATEVIRTIOBLKREQUEST']._serialized_start=905
  _globals['_UPDATEVIRTIOBLKREQUEST']._serialized_end=1107
  _globals['_LISTVIRTIOBLKSREQUEST']._serialized_start=1109
  _globals['_LISTVIRTIOBLKSREQUEST']._serialized_end=1204
  _globals['_LISTVIRTIOBLKSRESPONSE']._serialized_start=1207
  _globals['_LISTVIRTIOBLKSRESPONSE']._serialized_end=1335
  _globals['_GETVIRTIOBLKREQUEST']._serialized_start=1337
  _globals['_GETVIRTIOBLKREQUEST']._serialized_end=1417
  _globals['_STATSVIRTIOBLKREQUEST']._serialized_start=1419
  _globals['_STATSVIRTIOBLKREQUEST']._serialized_end=1501
  _globals['_STATSVIRTIOBLKRESPONSE']._serialized_start=1503
  _globals['_STATSVIRTIOBLKRESPONSE']._serialized_end=1582
  _globals['_FRONTENDVIRTIOBLKSERVICE']._serialized_start=1585
  _globals['_FRONTENDVIRTIOBLKSERVICE']._serialized_end=2481
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import frontend_virtio_blk_pb2 as frontend__virtio__blk__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FrontendVirtioBlkServiceStub(object):
    """Front End (host-facing) APIs. Mostly used for Virtio-blk emulation emulation and host presentation as alternative to Nvme.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateVirtioBlk = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioBlkService/CreateVirtioBlk',
                request_serializer=frontend__virtio__blk__pb2.CreateVirtioBlkRequest.SerializeToString,
                response_deserializer=frontend__virtio__blk__pb2.VirtioBlk.FromString,
                )
        self.DeleteVirtioBlk = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioBlkService/DeleteVirtioBlk',
                request_serializer=frontend__virtio__blk__pb2.DeleteVirtioBlkRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateVirtioBlk = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioBlkService/UpdateVirtioBlk',
                request_serializer=frontend__virtio__blk__pb2.UpdateVirtioBlkRequest.SerializeToString,
                response_deserializer=frontend__virtio__blk__pb2.VirtioBlk.FromString,
                )
        self.ListVirtioBlks = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioBlkService/ListVirtioBlks',
                request_serializer=frontend__virtio__blk__pb2.ListVirtioBlksRequest.SerializeToString,
                response_deserializer=frontend__virtio__blk__pb2.ListVirtioBlksResponse.FromString,
                )
        self.GetVirtioBlk = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioBlkService/GetVirtioBlk',
                request_serializer=frontend__virtio__blk__pb2.GetVirtioBlkRequest.SerializeToString,
                response_deserializer=frontend__virtio__blk__pb2.VirtioBlk.FromString,
                )
        self.StatsVirtioBlk = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioBlkService/StatsVirtioBlk',
                request_serializer=frontend__virtio__blk__pb2.StatsVirtioBlkRequest.SerializeToString,
                response_deserializer=frontend__virtio__blk__pb2.StatsVirtioBlkResponse.FromString,
                )


class FrontendVirtioBlkServiceServicer(object):
    """Front End (host-facing) APIs. Mostly used for Virtio-blk emulation emulation and host presentation as alternative to Nvme.
    """

    def CreateVirtioBlk(self, request, context):
        """Create an Virtio Blk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVirtioBlk(self, request, context):
        """Delete an Virtio Blk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVirtioBlk(self, request, context):
        """Update an Virtio Blk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVirtioBlks(self, request, context):
        """List Virtio Blks
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtioBlk(self, request, context):
        """Get an Virtio Blk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsVirtioBlk(self, request, context):
        """Get an Virtio Blk statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FrontendVirtioBlkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateVirtioBlk': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtioBlk,
                    request_deserializer=frontend__virtio__blk__pb2.CreateVirtioBlkRequest.FromString,
                    response_serializer=frontend__virtio__blk__pb2.VirtioBlk.SerializeToString,
            ),
            'DeleteVirtioBlk': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVirtioBlk,
                    request_deserializer=frontend__virtio__blk__pb2.DeleteVirtioBlkRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateVirtioBlk': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVirtioBlk,
                    request_deserializer=frontend__virtio__blk__pb2.UpdateVirtioBlkRequest.FromString,
                    response_serializer=frontend__virtio__blk__pb2.VirtioBlk.SerializeToString,
            ),
            'ListVirtioBlks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVirtioBlks,
                    request_deserializer=frontend__virtio__blk__pb2.ListVirtioBlksRequest.FromString,
                    response_serializer=frontend__virtio__blk__pb2.ListVirtioBlksResponse.SerializeToString,
            ),
            'GetVirtioBlk': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtioBlk,
                    request_deserializer=frontend__virtio__blk__pb2.GetVirtioBlkRequest.FromString,
                    response_serializer=frontend__virtio__blk__pb2.VirtioBlk.SerializeToString,
            ),
            'StatsVirtioBlk': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsVirtioBlk,
                    request_deserializer=frontend__virtio__blk__pb2.StatsVirtioBlkRequest.FromString,
                    response_serializer=frontend__virtio__blk__pb2.StatsVirtioBlkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.FrontendVirtioBlkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FrontendVirtioBlkService(object):
    """Front End (host-facing) APIs. Mostly used for Virtio-blk emulation emulation and host presentation as alternative to Nvme.
    """

    @staticmethod
    def CreateVirtioBlk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioBlkService/CreateVirtioBlk',
            frontend__virtio__blk__pb2.CreateVirtioBlkRequest.SerializeToString,
            frontend__virtio__blk__pb2.VirtioBlk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVirtioBlk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioBlkService/DeleteVirtioBlk',
            frontend__virtio__blk__pb2.DeleteVirtioBlkRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVirtioBlk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioBlkService/UpdateVirtioBlk',
            frontend__virtio__blk__pb2.UpdateVirtioBlkRequest.SerializeToString,
            frontend__virtio__blk__pb2.VirtioBlk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVirtioBlks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioBlkService/ListVirtioBlks',
            frontend__virtio__blk__pb2.ListVirtioBlksRequest.SerializeToString,
            frontend__virtio__blk__pb2.ListVirtioBlksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVirtioBlk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioBlkService/GetVirtioBlk',
            frontend__virtio__blk__pb2.GetVirtioBlkRequest.SerializeToString,
            frontend__virtio__blk__pb2.VirtioBlk.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsVirtioBlk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioBlkService/StatsVirtioBlk',
            frontend__virtio__blk__pb2.StatsVirtioBlkRequest.SerializeToString,
            frontend__virtio__blk__pb2.StatsVirtioBlkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import frontend_nvme_pb2 as frontend__nvme__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FrontendNvmeServiceStub(object):
    """Front End APIs. Used for creation of xPU managed Nvme devices
    e.g. emulated host-facing Nvme/Pcie controllers as well as
    Nvme-oF controllers
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNvmeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/CreateNvmeSubsystem',
                request_serializer=frontend__nvme__pb2.CreateNvmeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeSubsystem.FromString,
                )
        self.DeleteNvmeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/DeleteNvmeSubsystem',
                request_serializer=frontend__nvme__pb2.DeleteNvmeSubsystemRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNvmeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/UpdateNvmeSubsystem',
                request_serializer=frontend__nvme__pb2.UpdateNvmeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeSubsystem.FromString,
                )
        self.ListNvmeSubsystems = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/ListNvmeSubsystems',
                request_serializer=frontend__nvme__pb2.ListNvmeSubsystemsRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.ListNvmeSubsystemsResponse.FromString,
                )
        self.GetNvmeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/GetNvmeSubsystem',
                request_serializer=frontend__nvme__pb2.GetNvmeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeSubsystem.FromString,
                )
        self.StatsNvmeSubsystem = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/StatsNvmeSubsystem',
                request_serializer=frontend__nvme__pb2.StatsNvmeSubsystemRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.StatsNvmeSubsystemResponse.FromString,
                )
        self.CreateNvmeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/CreateNvmeController',
                request_serializer=frontend__nvme__pb2.CreateNvmeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeController.FromString,
                )
        self.DeleteNvmeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/DeleteNvmeController',
                request_serializer=frontend__nvme__pb2.DeleteNvmeControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNvmeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/UpdateNvmeController',
                request_serializer=frontend__nvme__pb2.UpdateNvmeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeController.FromString,
                )
        self.ListNvmeControllers = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/ListNvmeControllers',
                request_serializer=frontend__nvme__pb2.ListNvmeControllersRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.ListNvmeControllersResponse.FromString,
                )
        self.GetNvmeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/GetNvmeController',
                request_serializer=frontend__nvme__pb2.GetNvmeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeController.FromString,
                )
        self.StatsNvmeController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/StatsNvmeController',
                request_serializer=frontend__nvme__pb2.StatsNvmeControllerRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.StatsNvmeControllerResponse.FromString,
                )
        self.CreateNvmeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/CreateNvmeNamespace',
                request_serializer=frontend__nvme__pb2.CreateNvmeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeNamespace.FromString,
                )
        self.DeleteNvmeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/DeleteNvmeNamespace',
                request_serializer=frontend__nvme__pb2.DeleteNvmeNamespaceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNvmeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/UpdateNvmeNamespace',
                request_serializer=frontend__nvme__pb2.UpdateNvmeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeNamespace.FromString,
                )
        self.ListNvmeNamespaces = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/ListNvmeNamespaces',
                request_serializer=frontend__nvme__pb2.ListNvmeNamespacesRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.ListNvmeNamespacesResponse.FromString,
                )
        self.GetNvmeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/GetNvmeNamespace',
                request_serializer=frontend__nvme__pb2.GetNvmeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.NvmeNamespace.FromString,
                )
        self.StatsNvmeNamespace = channel.unary_unary(
                '/opi_api.storage.v1.FrontendNvmeService/StatsNvmeNamespace',
                request_serializer=frontend__nvme__pb2.StatsNvmeNamespaceRequest.SerializeToString,
                response_deserializer=frontend__nvme__pb2.StatsNvmeNamespaceResponse.FromString,
                )


class FrontendNvmeServiceServicer(object):
    """Front End APIs. Used for creation of xPU managed Nvme devices
    e.g. emulated host-facing Nvme/Pcie controllers as well as
    Nvme-oF controllers
    """

    def CreateNvmeSubsystem(self, request, context):
        """Create an Nvme Subsystem
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNvmeSubsystem(self, request, context):
        """Delete an Nvme Subsystem
        Fails if there are any associated objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNvmeSubsystem(self, request, context):
        """Update an Nvme Subsystem
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNvmeSubsystems(self, request, context):
        """List Nvme Subsystems
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNvmeSubsystem(self, request, context):
        """Get an Nvme Subsystem
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsNvmeSubsystem(self, request, context):
        """Get an Nvme Subsystem statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNvmeController(self, request, context):
        """Create an Nvme Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNvmeController(self, request, context):
        """Delete an Nvme Controller
        Fails if there are any associated objects
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNvmeController(self, request, context):
        """Update an Nvme Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNvmeControllers(self, request, context):
        """List Nvme Controllers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNvmeController(self, request, context):
        """Get an Nvme Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsNvmeController(self, request, context):
        """Get an Nvme Controller statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNvmeNamespace(self, request, context):
        """Create an Nvme Namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNvmeNamespace(self, request, context):
        """Delete an Nvme Namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNvmeNamespace(self, request, context):
        """Update an Nvme Namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNvmeNamespaces(self, request, context):
        """List Nvme Namespaces
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNvmeNamespace(self, request, context):
        """Get an Nvme Namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsNvmeNamespace(self, request, context):
        """Get an Nvme Namespace statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FrontendNvmeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNvmeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNvmeSubsystem,
                    request_deserializer=frontend__nvme__pb2.CreateNvmeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeSubsystem.SerializeToString,
            ),
            'DeleteNvmeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNvmeSubsystem,
                    request_deserializer=frontend__nvme__pb2.DeleteNvmeSubsystemRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNvmeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNvmeSubsystem,
                    request_deserializer=frontend__nvme__pb2.UpdateNvmeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeSubsystem.SerializeToString,
            ),
            'ListNvmeSubsystems': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNvmeSubsystems,
                    request_deserializer=frontend__nvme__pb2.ListNvmeSubsystemsRequest.FromString,
                    response_serializer=frontend__nvme__pb2.ListNvmeSubsystemsResponse.SerializeToString,
            ),
            'GetNvmeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNvmeSubsystem,
                    request_deserializer=frontend__nvme__pb2.GetNvmeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeSubsystem.SerializeToString,
            ),
            'StatsNvmeSubsystem': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsNvmeSubsystem,
                    request_deserializer=frontend__nvme__pb2.StatsNvmeSubsystemRequest.FromString,
                    response_serializer=frontend__nvme__pb2.StatsNvmeSubsystemResponse.SerializeToString,
            ),
            'CreateNvmeController': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNvmeController,
                    request_deserializer=frontend__nvme__pb2.CreateNvmeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeController.SerializeToString,
            ),
            'DeleteNvmeController': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNvmeController,
                    request_deserializer=frontend__nvme__pb2.DeleteNvmeControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNvmeController': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNvmeController,
                    request_deserializer=frontend__nvme__pb2.UpdateNvmeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeController.SerializeToString,
            ),
            'ListNvmeControllers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNvmeControllers,
                    request_deserializer=frontend__nvme__pb2.ListNvmeControllersRequest.FromString,
                    response_serializer=frontend__nvme__pb2.ListNvmeControllersResponse.SerializeToString,
            ),
            'GetNvmeController': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNvmeController,
                    request_deserializer=frontend__nvme__pb2.GetNvmeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeController.SerializeToString,
            ),
            'StatsNvmeController': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsNvmeController,
                    request_deserializer=frontend__nvme__pb2.StatsNvmeControllerRequest.FromString,
                    response_serializer=frontend__nvme__pb2.StatsNvmeControllerResponse.SerializeToString,
            ),
            'CreateNvmeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNvmeNamespace,
                    request_deserializer=frontend__nvme__pb2.CreateNvmeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeNamespace.SerializeToString,
            ),
            'DeleteNvmeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNvmeNamespace,
                    request_deserializer=frontend__nvme__pb2.DeleteNvmeNamespaceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNvmeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNvmeNamespace,
                    request_deserializer=frontend__nvme__pb2.UpdateNvmeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeNamespace.SerializeToString,
            ),
            'ListNvmeNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNvmeNamespaces,
                    request_deserializer=frontend__nvme__pb2.ListNvmeNamespacesRequest.FromString,
                    response_serializer=frontend__nvme__pb2.ListNvmeNamespacesResponse.SerializeToString,
            ),
            'GetNvmeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNvmeNamespace,
                    request_deserializer=frontend__nvme__pb2.GetNvmeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pb2.NvmeNamespace.SerializeToString,
            ),
            'StatsNvmeNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsNvmeNamespace,
                    request_deserializer=frontend__nvme__pb2.StatsNvmeNamespaceRequest.FromString,
                    response_serializer=frontend__nvme__pb2.StatsNvmeNamespaceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.FrontendNvmeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FrontendNvmeService(object):
    """Front End APIs. Used for creation of xPU managed Nvme devices
    e.g. emulated host-facing Nvme/Pcie controllers as well as
    Nvme-oF controllers
    """

    @staticmethod
    def CreateNvmeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/CreateNvmeSubsystem',
            frontend__nvme__pb2.CreateNvmeSubsystemRequest.SerializeToString,
            frontend__nvme__pb2.NvmeSubsystem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNvmeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/DeleteNvmeSubsystem',
            frontend__nvme__pb2.DeleteNvmeSubsystemRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNvmeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/UpdateNvmeSubsystem',
            frontend__nvme__pb2.UpdateNvmeSubsystemRequest.SerializeToString,
            frontend__nvme__pb2.NvmeSubsystem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNvmeSubsystems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/ListNvmeSubsystems',
            frontend__nvme__pb2.ListNvmeSubsystemsRequest.SerializeToString,
            frontend__nvme__pb2.ListNvmeSubsystemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNvmeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/GetNvmeSubsystem',
            frontend__nvme__pb2.GetNvmeSubsystemRequest.SerializeToString,
            frontend__nvme__pb2.NvmeSubsystem.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsNvmeSubsystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/StatsNvmeSubsystem',
            frontend__nvme__pb2.StatsNvmeSubsystemRequest.SerializeToString,
            frontend__nvme__pb2.StatsNvmeSubsystemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNvmeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/CreateNvmeController',
            frontend__nvme__pb2.CreateNvmeControllerRequest.SerializeToString,
            frontend__nvme__pb2.NvmeController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNvmeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/DeleteNvmeController',
            frontend__nvme__pb2.DeleteNvmeControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNvmeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/UpdateNvmeController',
            frontend__nvme__pb2.UpdateNvmeControllerRequest.SerializeToString,
            frontend__nvme__pb2.NvmeController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNvmeControllers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/ListNvmeControllers',
            frontend__nvme__pb2.ListNvmeControllersRequest.SerializeToString,
            frontend__nvme__pb2.ListNvmeControllersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNvmeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/GetNvmeController',
            frontend__nvme__pb2.GetNvmeControllerRequest.SerializeToString,
            frontend__nvme__pb2.NvmeController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsNvmeController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/StatsNvmeController',
            frontend__nvme__pb2.StatsNvmeControllerRequest.SerializeToString,
            frontend__nvme__pb2.StatsNvmeControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNvmeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/CreateNvmeNamespace',
            frontend__nvme__pb2.CreateNvmeNamespaceRequest.SerializeToString,
            frontend__nvme__pb2.NvmeNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNvmeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/DeleteNvmeNamespace',
            frontend__nvme__pb2.DeleteNvmeNamespaceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNvmeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/UpdateNvmeNamespace',
            frontend__nvme__pb2.UpdateNvmeNamespaceRequest.SerializeToString,
            frontend__nvme__pb2.NvmeNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNvmeNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/ListNvmeNamespaces',
            frontend__nvme__pb2.ListNvmeNamespacesRequest.SerializeToString,
            frontend__nvme__pb2.ListNvmeNamespacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNvmeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/GetNvmeNamespace',
            frontend__nvme__pb2.GetNvmeNamespaceRequest.SerializeToString,
            frontend__nvme__pb2.NvmeNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsNvmeNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendNvmeService/StatsNvmeNamespace',
            frontend__nvme__pb2.StatsNvmeNamespaceRequest.SerializeToString,
            frontend__nvme__pb2.StatsNvmeNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: middleend_qos_volume.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1amiddleend_qos_volume.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xdc\x01\n\tQosVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12,\n\x0fvolume_name_ref\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef\x12\x38\n\x06limits\x18\x03 \x01(\x0b\x32\x1a.opi_api.storage.v1.LimitsB\x04\xe2\x41\x01\x02R\x06limits:M\xea\x41J\n\x1copi_api.storage.v1/QosVolume\x12\x13qosVolumes/{volume}*\nqosVolumes2\tqosVolume\"t\n\x06Limits\x12\x34\n\x03min\x18\x01 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x03min\x12\x34\n\x03max\x18\x02 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x03max\"\x86\x01\n\x16\x43reateQosVolumeRequest\x12\x42\n\nqos_volume\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.QosVolumeB\x04\xe2\x41\x01\x02R\tqosVolume\x12(\n\rqos_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0bqosVolumeId\"~\n\x16\x44\x65leteQosVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/QosVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xca\x01\n\x16UpdateQosVolumeRequest\x12\x42\n\nqos_volume\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.QosVolumeB\x04\xe2\x41\x01\x02R\tqosVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\x9e\x01\n\x15ListQosVolumesRequest\x12=\n\x06parent\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\x12\x1copi_api.storage.v1/QosVolumeR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x80\x01\n\x16ListQosVolumesResponse\x12>\n\x0bqos_volumes\x18\x01 \x03(\x0b\x32\x1d.opi_api.storage.v1.QosVolumeR\nqosVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x13GetQosVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/QosVolumeR\x04name\"R\n\x15StatsQosVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/QosVolumeR\x04name\"O\n\x16StatsQosVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\x91\x07\n\x19MiddleendQosVolumeService\x12\x9b\x01\n\x0f\x43reateQosVolume\x12*.opi_api.storage.v1.CreateQosVolumeRequest\x1a\x1d.opi_api.storage.v1.QosVolume\"=\xda\x41\x18qos_volume,qos_volume_id\x82\xd3\xe4\x93\x02\x1c\"\x0e/v1/qosVolumes:\nqos_volume\x12}\n\x0f\x44\x65leteQosVolume\x12*.opi_api.storage.v1.DeleteQosVolumeRequest\x1a\x16.google.protobuf.Empty\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19*\x17/v1/{name=qosVolumes/*}\x12\xad\x01\n\x0fUpdateQosVolume\x12*.opi_api.storage.v1.UpdateQosVolumeRequest\x1a\x1d.opi_api.storage.v1.QosVolume\"O\xda\x41\x16qos_volume,update_mask\x82\xd3\xe4\x93\x02\x30\x32\"/v1/{qos_volume.name=qosVolumes/*}:\nqos_volume\x12\x8e\x01\n\x0eListQosVolumes\x12).opi_api.storage.v1.ListQosVolumesRequest\x1a*.opi_api.storage.v1.ListQosVolumesResponse\"%\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{parent=volumes}\x12~\n\x0cGetQosVolume\x12\'.opi_api.storage.v1.GetQosVolumeRequest\x1a\x1d.opi_api.storage.v1.QosVolume\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{name=qosVolumes/*}\x12\x95\x01\n\x0eStatsQosVolume\x12).opi_api.storage.v1.StatsQosVolumeRequest\x1a*.opi_api.storage.v1.StatsQosVolumeResponse\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=qosVolumes/*}:statsBf\n\x12opi_api.storage.v1B\x17MiddleendQosVolumeProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'middleend_qos_volume_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\027MiddleendQosVolumeProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_QOSVOLUME'].fields_by_name['name']._options = None
  _globals['_QOSVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_QOSVOLUME'].fields_by_name['volume_name_ref']._options = None
  _globals['_QOSVOLUME'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_QOSVOLUME'].fields_by_name['limits']._options = None
  _globals['_QOSVOLUME'].fields_by_name['limits']._serialized_options = b'\342A\001\002'
  _globals['_QOSVOLUME']._options = None
  _globals['_QOSVOLUME']._serialized_options = b'\352AJ\n\034opi_api.storage.v1/QosVolume\022\023qosVolumes/{volume}*\nqosVolumes2\tqosVolume'
  _globals['_LIMITS'].fields_by_name['min']._options = None
  _globals['_LIMITS'].fields_by_name['min']._serialized_options = b'\342A\001\001'
  _globals['_LIMITS'].fields_by_name['max']._options = None
  _globals['_LIMITS'].fields_by_name['max']._serialized_options = b'\342A\001\001'
  _globals['_CREATEQOSVOLUMEREQUEST'].fields_by_name['qos_volume']._options = None
  _globals['_CREATEQOSVOLUMEREQUEST'].fields_by_name['qos_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATEQOSVOLUMEREQUEST'].fields_by_name['qos_volume_id']._options = None
  _globals['_CREATEQOSVOLUMEREQUEST'].fields_by_name['qos_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEQOSVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEQOSVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/QosVolume'
  _globals['_DELETEQOSVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEQOSVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEQOSVOLUMEREQUEST'].fields_by_name['qos_volume']._options = None
  _globals['_UPDATEQOSVOLUMEREQUEST'].fields_by_name['qos_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEQOSVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEQOSVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEQOSVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEQOSVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTQOSVOLUMESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTQOSVOLUMESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\036\022\034opi_api.storage.v1/QosVolume'
  _globals['_LISTQOSVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTQOSVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTQOSVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTQOSVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETQOSVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETQOSVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/QosVolume'
  _globals['_STATSQOSVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSQOSVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/QosVolume'
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['CreateQosVolume']._options = None
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['CreateQosVolume']._serialized_options = b'\332A\030qos_volume,qos_volume_id\202\323\344\223\002\034\"\016/v1/qosVolumes:\nqos_volume'
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['DeleteQosVolume']._options = None
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['DeleteQosVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\031*\027/v1/{name=qosVolumes/*}'
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['UpdateQosVolume']._options = None
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['UpdateQosVolume']._serialized_options = b'\332A\026qos_volume,update_mask\202\323\344\223\00202\"/v1/{qos_volume.name=qosVolumes/*}:\nqos_volume'
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['ListQosVolumes']._options = None
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['ListQosVolumes']._serialized_options = b'\332A\006parent\202\323\344\223\002\026\022\024/v1/{parent=volumes}'
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['GetQosVolume']._options = None
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['GetQosVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\031\022\027/v1/{name=qosVolumes/*}'
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['StatsQosVolume']._options = None
  _globals['_MIDDLEENDQOSVOLUMESERVICE'].methods_by_name['StatsQosVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\037\022\035/v1/{name=qosVolumes/*}:stats'
  _globals['_QOSVOLUME']._serialized_start=246
  _globals['_QOSVOLUME']._serialized_end=466
  _globals['_LIMITS']._serialized_start=468
  _globals['_LIMITS']._serialized_end=584
  _globals['_CREATEQOSVOLUMEREQUEST']._serialized_start=587
  _globals['_CREATEQOSVOLUMEREQUEST']._serialized_end=721
  _globals['_DELETEQOSVOLUMEREQUEST']._serialized_start=723
  _globals['_DELETEQOSVOLUMEREQUEST']._serialized_end=849
  _globals['_UPDATEQOSVOLUMEREQUEST']._serialized_start=852
  _globals['_UPDATEQOSVOLUMEREQUEST']._serialized_end=1054
  _globals['_LISTQOSVOLUMESREQUEST']._serialized_start=1057
  _globals['_LISTQOSVOLUMESREQUEST']._serialized_end=1215
  _globals['_LISTQOSVOLUMESRESPONSE']._serialized_start=1218
  _globals['_LISTQOSVOLUMESRESPONSE']._serialized_end=1346
  _globals['_GETQOSVOLUMEREQUEST']._serialized_start=1348
  _globals['_GETQOSVOLUMEREQUEST']._serialized_end=1428
  _globals['_STATSQOSVOLUMEREQUEST']._serialized_start=1430
  _globals['_STATSQOSVOLUMEREQUEST']._serialized_end=1512
  _globals['_STATSQOSVOLUMERESPONSE']._serialized_start=1514
  _globals['_STATSQOSVOLUMERESPONSE']._serialized_end=1593
  _globals['_MIDDLEENDQOSVOLUMESERVICE']._serialized_start=1596
  _globals['_MIDDLEENDQOSVOLUMESERVICE']._serialized_end=2509
# @@protoc_insertion_point(module_scope)



"""Console script for pydpu."""
import click
import grpc

from .dpuredfish import accounts, certificates, managers, systems, update
from .evpn import bridge_create, port_create, svi_create, vrf_create
from .inventory import get_inventory
from .ipsec import create_new_tunnel, get_stats
from .storage import NvmeController, NvmeNamespace, NvmeSubsystem


@click.group()
@click.version_option(None, "-V", "--version")
@click.option("--address", help="IP address of the DPU gRPC management.", required=True)
@click.pass_context
def main(ctx, address):
    # ensure that ctx.obj exists and is a dict (in case `cli()` is called
    # by means other than the `if` block below)
    ctx.ensure_object(dict)
    ctx.obj["ADDRESS"] = address


@main.group()
@click.pass_context
def inventory(ctx):
    pass  # pragma: no cover


@inventory.command()
@click.pass_context
def get(ctx):
    get_inventory(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@main.group()
@click.pass_context
def evpn(ctx):
    pass  # pragma: no cover


@evpn.command()
@click.pass_context
def bridge(ctx):
    bridge_create(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@evpn.command()
@click.pass_context
def port(ctx):
    port_create(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@evpn.command()
@click.pass_context
def vrf(ctx):
    vrf_create(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@evpn.command()
@click.pass_context
def svi(ctx):
    svi_create(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@main.group()
@click.pass_context
def ipsec(ctx):
    pass  # pragma: no cover


@ipsec.command()
@click.pass_context
def create_tunnel(ctx, **kwargs):
    create_new_tunnel(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@ipsec.command()
@click.pass_context
def stats(ctx, **kwargs):
    get_stats(ctx.obj["ADDRESS"])
    click.echo("work in progress")


@main.group()
@click.pass_context
def storage(ctx):
    pass  # pragma: no cover


@storage.command()
@click.pass_context
def show(ctx, **kwargs):
    click.echo("work in progress")
    try:
        s = NvmeSubsystem(
            nqn="nqn.2022-09.io.spdk:opi1", model="OPI Model", serial="OPI SN"
        )
        click.echo(s)
        res = s.list(ctx.obj["ADDRESS"])
        click.echo(res)
    except grpc.RpcError as e:
        print(e)
        # raise


@storage.command()
@click.pass_context
def subsystem(ctx, **kwargs):
    click.echo("work in progress")
    try:
        s = NvmeSubsystem(
            nqn="nqn.2022-09.io.spdk:opi1", model="OPI Model", serial="OPI SN"
        )
        click.echo(s)
        res = s.create(ctx.obj["ADDRESS"])
        click.echo(res)
        # res = s.update(ctx.obj["ADDRESS"])
        # click.echo(res)
        res = s.list(ctx.obj["ADDRESS"])
        click.echo(res)
        res = s.get(ctx.obj["ADDRESS"])
        click.echo(res)
        res = s.stats(ctx.obj["ADDRESS"])
        click.echo(res)
        res = s.delete(ctx.obj["ADDRESS"])
        click.echo(res)
    except grpc.RpcError as e:
        print(e)
        # raise


@storage.command()
@click.pass_context
def controller(ctx, **kwargs):
    click.echo("work in progress")
    try:
        s = NvmeSubsystem(
            nqn="nqn.2022-09.io.spdk:opi1", model="OPI Model", serial="OPI SN"
        )
        click.echo(s)
        c = NvmeController(
            subsystem=s, queue=1024, pf=0, vf=0, port=0, max_nsq=8, max_ncq=8
        )
        click.echo(c)
        res = c.create(ctx.obj["ADDRESS"])
        click.echo(res)
        # res = c.update(ctx.obj["ADDRESS"])
        # click.echo(res)
        res = c.list(ctx.obj["ADDRESS"])
        click.echo(res)
        res = c.get(ctx.obj["ADDRESS"])
        click.echo(res)
        res = c.stats(ctx.obj["ADDRESS"])
        click.echo(res)
        res = c.delete(ctx.obj["ADDRESS"])
        click.echo(res)
    except grpc.RpcError as e:
        click.echo(e)
        # raise


@storage.command()
@click.pass_context
def namespace(ctx, **kwargs):
    click.echo("work in progress")
    try:
        s = NvmeSubsystem(
            nqn="nqn.2022-09.io.spdk:opi1", model="OPI Model", serial="OPI SN"
        )
        click.echo(s)
        n = NvmeNamespace(subsystem=s, volume="Malloc1")
        click.echo(n)
        res = n.create(ctx.obj["ADDRESS"])
        click.echo(res)
        # res = n.update(ctx.obj["ADDRESS"])
        # click.echo(res)
        res = n.list(ctx.obj["ADDRESS"])
        click.echo(res)
        res = n.get(ctx.obj["ADDRESS"])
        click.echo(res)
        res = n.stats(ctx.obj["ADDRESS"])
        click.echo(res)
        res = n.delete(ctx.obj["ADDRESS"])
        click.echo(res)
    except grpc.RpcError as e:
        click.echo(e)
        # raise


@main.group()
@click.option("-u", "--username", default="root", help="DPU BMC redfish username")
@click.option("-p", "--password", default="0penBmc", help="DPU BMC redfish password")
@click.pass_context
def redfish(ctx, username, password):
    # ensure that ctx.obj exists and is a dict (in case `cli()` is called
    # by means other than the `if` block below)
    ctx.ensure_object(dict)
    ctx.obj["USERNAME"] = username
    ctx.obj["PASSWORD"] = password


@redfish.command()
@click.pass_context
def test(ctx, **kwargs):
    s = systems.Systems(ctx.obj["ADDRESS"], ctx.obj["USERNAME"], ctx.obj["PASSWORD"])
    click.echo(list(s.get_processors()))
    m = managers.Managers(ctx.obj["ADDRESS"], ctx.obj["USERNAME"], ctx.obj["PASSWORD"])
    click.echo(m.get_bmc_datetime())
    a = accounts.AccountService(
        ctx.obj["ADDRESS"], ctx.obj["USERNAME"], ctx.obj["PASSWORD"]
    )
    click.echo(list(a.get_accounts()))
    c = certificates.CertificateService(
        ctx.obj["ADDRESS"], ctx.obj["USERNAME"], ctx.obj["PASSWORD"]
    )
    click.echo(list(c.get_certificates()))
    u = update.UpdateService(
        ctx.obj["ADDRESS"], ctx.obj["USERNAME"], ctx.obj["PASSWORD"]
    )
    click.echo(list(u.get_versions()))


if __name__ == "__main__":
    main()  # pragma: no cover



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opicommon.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fopicommon.proto\x12\x12opi_api.storage.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xe7\x01\n\x0bPciEndpoint\x12:\n\x07port_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x04\xe2\x41\x01\x02R\x06portId\x12N\n\x11physical_function\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x04\xe2\x41\x01\x02R\x10physicalFunction\x12L\n\x10virtual_function\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x04\xe2\x41\x01\x02R\x0fvirtualFunction\"\x94\x01\n\x0f\x46\x61\x62ricsEndpoint\x12\x1c\n\x06traddr\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x06traddr\x12\x1e\n\x07trsvcid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07trsvcid\x12\x43\n\x06\x61\x64rfam\x18\x03 \x01(\x0e\x32%.opi_api.storage.v1.NvmeAddressFamilyB\x04\xe2\x41\x01\x02R\x06\x61\x64rfam\"\xc9\x03\n\x0bVolumeStats\x12.\n\x10read_bytes_count\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0ereadBytesCount\x12*\n\x0eread_ops_count\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0creadOpsCount\x12\x30\n\x11write_bytes_count\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0fwriteBytesCount\x12,\n\x0fwrite_ops_count\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\rwriteOpsCount\x12\x30\n\x11unmap_bytes_count\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0funmapBytesCount\x12,\n\x0funmap_ops_count\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x03R\runmapOpsCount\x12\x32\n\x12read_latency_ticks\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x10readLatencyTicks\x12\x34\n\x13write_latency_ticks\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x11writeLatencyTicks\x12\x34\n\x13unmap_latency_ticks\x18\t \x01(\x05\x42\x04\xe2\x41\x01\x03R\x11unmapLatencyTicks\"\x98\x02\n\x08QosLimit\x12(\n\rrd_iops_kiops\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0brdIopsKiops\x12(\n\rwr_iops_kiops\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0bwrIopsKiops\x12(\n\rrw_iops_kiops\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0brwIopsKiops\x12.\n\x10rd_bandwidth_mbs\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0erdBandwidthMbs\x12.\n\x10wr_bandwidth_mbs\x18\x05 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0ewrBandwidthMbs\x12.\n\x10rw_bandwidth_mbs\x18\x06 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0erwBandwidthMbs*\xf7\x01\n\x0e\x45ncryptionType\x12\x1f\n\x1b\x45NCRYPTION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_128\x10\x01\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_192\x10\x02\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_256\x10\x03\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_128\x10\x04\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_192\x10\x05\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_256\x10\x06*\xcd\x01\n\x11NvmeTransportType\x12#\n\x1fNVME_TRANSPORT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16NVME_TRANSPORT_TYPE_FC\x10\x01\x12\x1c\n\x18NVME_TRANSPORT_TYPE_PCIE\x10\x02\x12\x1c\n\x18NVME_TRANSPORT_TYPE_RDMA\x10\x03\x12\x1b\n\x17NVME_TRANSPORT_TYPE_TCP\x10\x04\x12\x1e\n\x1aNVME_TRANSPORT_TYPE_CUSTOM\x10\x05*\xd0\x01\n\x11NvmeAddressFamily\x12#\n\x1fNVME_ADDRESS_FAMILY_UNSPECIFIED\x10\x00\x12\x1c\n\x18NVME_ADDRESS_FAMILY_IPV4\x10\x01\x12\x1c\n\x18NVME_ADDRESS_FAMILY_IPV6\x10\x02\x12\x1a\n\x16NVME_ADDRESS_FAMILY_IB\x10\x03\x12\x1a\n\x16NVME_ADDRESS_FAMILY_FC\x10\x04\x12\"\n\x1eNVME_ADDRESS_FAMILY_INTRA_HOST\x10\x05\x42]\n\x12opi_api.storage.v1B\x0eOpiCommonProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opicommon_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\016OpiCommonProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_PCIENDPOINT'].fields_by_name['port_id']._options = None
  _globals['_PCIENDPOINT'].fields_by_name['port_id']._serialized_options = b'\342A\001\002'
  _globals['_PCIENDPOINT'].fields_by_name['physical_function']._options = None
  _globals['_PCIENDPOINT'].fields_by_name['physical_function']._serialized_options = b'\342A\001\002'
  _globals['_PCIENDPOINT'].fields_by_name['virtual_function']._options = None
  _globals['_PCIENDPOINT'].fields_by_name['virtual_function']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSENDPOINT'].fields_by_name['traddr']._options = None
  _globals['_FABRICSENDPOINT'].fields_by_name['traddr']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSENDPOINT'].fields_by_name['trsvcid']._options = None
  _globals['_FABRICSENDPOINT'].fields_by_name['trsvcid']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSENDPOINT'].fields_by_name['adrfam']._options = None
  _globals['_FABRICSENDPOINT'].fields_by_name['adrfam']._serialized_options = b'\342A\001\002'
  _globals['_VOLUMESTATS'].fields_by_name['read_bytes_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['read_bytes_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['read_ops_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['read_ops_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['write_bytes_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['write_bytes_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['write_ops_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['write_ops_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['unmap_bytes_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['unmap_bytes_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['unmap_ops_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['unmap_ops_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['read_latency_ticks']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['read_latency_ticks']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['write_latency_ticks']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['write_latency_ticks']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['unmap_latency_ticks']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['unmap_latency_ticks']._serialized_options = b'\342A\001\003'
  _globals['_QOSLIMIT'].fields_by_name['rd_iops_kiops']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rd_iops_kiops']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['wr_iops_kiops']._options = None
  _globals['_QOSLIMIT'].fields_by_name['wr_iops_kiops']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['rw_iops_kiops']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rw_iops_kiops']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['rd_bandwidth_mbs']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rd_bandwidth_mbs']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['wr_bandwidth_mbs']._options = None
  _globals['_QOSLIMIT'].fields_by_name['wr_bandwidth_mbs']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['rw_bandwidth_mbs']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rw_bandwidth_mbs']._serialized_options = b'\342A\001\001'
  _globals['_ENCRYPTIONTYPE']._serialized_start=1233
  _globals['_ENCRYPTIONTYPE']._serialized_end=1480
  _globals['_NVMETRANSPORTTYPE']._serialized_start=1483
  _globals['_NVMETRANSPORTTYPE']._serialized_end=1688
  _globals['_NVMEADDRESSFAMILY']._serialized_start=1691
  _globals['_NVMEADDRESSFAMILY']._serialized_end=1899
  _globals['_PCIENDPOINT']._serialized_start=105
  _globals['_PCIENDPOINT']._serialized_end=336
  _globals['_FABRICSENDPOINT']._serialized_start=339
  _globals['_FABRICSENDPOINT']._serialized_end=487
  _globals['_VOLUMESTATS']._serialized_start=490
  _globals['_VOLUMESTATS']._serialized_end=947
  _globals['_QOSLIMIT']._serialized_start=950
  _globals['_QOSLIMIT']._serialized_end=1230
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vnic.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nvnic.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xd3\x01\n\x04Vnic\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12<\n\x04spec\x18\x02 \x01(\x0b\x32(.opi_api.network.cloud.v1alpha1.VnicSpecR\x04spec\x12\x42\n\x06status\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.VnicStatusR\x06status:5\xea\x41\x32\n#opi_api.network.cloud.v1alpha1/vnic\x12\x0bvnic/{vnic}\"\x9b\n\n\x08VnicSpec\x12&\n\x0fsubnet_name_ref\x18\x01 \x01(\tR\rsubnetNameRef\x12K\n\nvnic_encap\x18\x02 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\tvnicEncap\x12\x1f\n\x0bmac_address\x18\x03 \x01(\x0cR\nmacAddress\x12.\n\x13source_guard_enable\x18\x04 \x01(\x08R\x11sourceGuardEnable\x12O\n\x0c\x66\x61\x62ric_encap\x18\x05 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x0b\x66\x61\x62ricEncap\x12\x10\n\x03vnf\x18\x06 \x01(\x08R\x03vnf\x12K\n#ingress_v4_security_policy_name_ref\x18\x07 \x03(\tR\x1eingressV4SecurityPolicyNameRef\x12K\n#ingress_v6_security_policy_name_ref\x18\x08 \x03(\tR\x1eingressV6SecurityPolicyNameRef\x12I\n\"egress_v4_security_policy_name_ref\x18\t \x03(\tR\x1d\x65gressV4SecurityPolicyNameRef\x12I\n\"egress_v6_security_policy_name_ref\x18\n \x03(\tR\x1d\x65gressV6SecurityPolicyNameRef\x12)\n\x10host_if_name_ref\x18\x0b \x01(\tH\x00R\rhostIfNameRef\x12(\n\x0ftunnel_name_ref\x18\x0c \x01(\tH\x00R\rtunnelNameRef\x12!\n\x0cmax_sessions\x18\r \x01(\x05R\x0bmaxSessions\x12,\n\x12public_mac_address\x18\x0e \x01(\x0cR\x10publicMacAddress\x12\x32\n\x15\x61llow_internet_access\x18\x0f \x01(\x08R\x13\x61llowInternetAccess\x12\x17\n\x07max_cps\x18\x10 \x01(\x05R\x06maxCps\x12\x1b\n\tcps_burst\x18\x11 \x01(\x05R\x08\x63psBurst\x12\x31\n\x15primary_vnic_name_ref\x18\x12 \x01(\tR\x12primaryVnicNameRef\x12\x34\n\x17v4_route_table_name_ref\x18\x13 \x01(\tR\x13v4RouteTableNameRef\x12\x34\n\x17v6_route_table_name_ref\x18\x14 \x01(\tR\x13v6RouteTableNameRef\x12O\n\nservice_ip\x18\x15 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tserviceIp\x12(\n\x10max_tcp_sessions\x18\x16 \x01(\x05R\x0emaxTcpSessions\x12(\n\x10max_udp_sessions\x18\x17 \x01(\x05R\x0emaxUdpSessions\x12*\n\x11max_icmp_sessions\x18\x18 \x01(\x05R\x0fmaxIcmpSessions\x12,\n\x12max_other_sessions\x18\x19 \x01(\x05R\x10maxOtherSessionsB\x08\n\x06ifinfo\"\xc8\x03\n\nVnicStatus\x12\x31\n\x15max_session_limit_hit\x18\r \x01(\x08R\x12maxSessionLimitHit\x12\x38\n\x19max_tcp_session_limit_hit\x18\x0e \x01(\x08R\x15maxTcpSessionLimitHit\x12\x38\n\x19max_udp_session_limit_hit\x18\x0f \x01(\x08R\x15maxUdpSessionLimitHit\x12:\n\x1amax_icmp_session_limit_hit\x18\x10 \x01(\x08R\x16maxIcmpSessionLimitHit\x12<\n\x1bmax_other_session_limit_hit\x18\x11 \x01(\x08R\x17maxOtherSessionLimitHit\x12\x15\n\x06hw_idx\x18\x01 \x01(\x05R\x05hwIdx\x12$\n\x0enexthop_hw_idx\x18\x02 \x01(\x05R\x0cnexthopHwIdx\x12%\n\x0f\x63ps_copp_hw_idx\x18\n \x01(\x05R\x0c\x63psCoppHwIdx\x12\x35\n\x17secondary_vnic_name_ref\x18\x0b \x01(\tR\x14secondaryVnicNameRefBj\n\x1eopi_api.network.cloud.v1alpha1B\tVnicProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vnic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\tVnicProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_VNIC']._options = None
  _globals['_VNIC']._serialized_options = b'\352A2\n#opi_api.network.cloud.v1alpha1/vnic\022\013vnic/{vnic}'
  _globals['_VNIC']._serialized_start=94
  _globals['_VNIC']._serialized_end=305
  _globals['_VNICSPEC']._serialized_start=308
  _globals['_VNICSPEC']._serialized_end=1615
  _globals['_VNICSTATUS']._serialized_start=1618
  _globals['_VNICSTATUS']._serialized_end=2074
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapping.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rmapping.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xe6\x01\n\x07Mapping\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.MappingSpecR\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.MappingStatusR\x06status:?\xea\x41<\n&opi_api.network.cloud.v1alpha1/mapping\x12\x12mappings/{mapping}\"\xdd\x04\n\x0bMappingSpec\x12\x45\n\x06ip_key\x18\x01 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.L3MappingKeyH\x00R\x05ipKey\x12G\n\x07mac_key\x18\x02 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.L2MappingKeyH\x00R\x06macKey\x12&\n\x0fsubnet_name_ref\x18\x03 \x01(\tR\rsubnetNameRef\x12$\n\rvnic_name_ref\x18\x04 \x01(\tH\x01R\x0bvnicNameRef\x12(\n\x0ftunnel_name_ref\x18\x05 \x01(\tH\x01R\rtunnelNameRef\x12+\n\x11nh_group_name_ref\x18\x06 \x01(\tH\x01R\x0enhGroupNameRef\x12\x19\n\x08mac_addr\x18\x07 \x01(\x0cR\x07macAddr\x12\x42\n\x05\x65ncap\x18\x08 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x05\x65ncap\x12M\n\tpublic_ip\x18\t \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08publicIp\x12\x12\n\x04tags\x18\n \x03(\rR\x04tags\x12?\n\x04type\x18\x0b \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.MappingTypeR\x04typeB\x0b\n\tmac_or_ipB\t\n\x07\x64stinfo\"\xa0\x03\n\rMappingStatus\x12(\n\x10public_nat_index\x18\x01 \x01(\x05R\x0epublicNatIndex\x12*\n\x11private_nat_index\x18\x02 \x01(\x05R\x0fprivateNatIndex\x12M\n\ttunnel_ip\x18\x03 \x03(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08tunnelIp\x12\x63\n\x16svc_port_map_hw_handle\x18\x04 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x12svcPortMapHwHandle\x12`\n\x14vnf_tunnel_hw_handle\x18\x05 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x11vnfTunnelHwHandle\x12#\n\rrewrite_index\x18\x06 \x01(\x05R\x0crewriteIndex\"\x81\x01\n\x0cL3MappingKey\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12O\n\nip_address\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tipAddress\"W\n\x0cL2MappingKey\x12&\n\x0fsubnet_name_ref\x18\x01 \x01(\tR\rsubnetNameRef\x12\x1f\n\x0bmac_address\x18\x02 \x01(\x0cR\nmacAddress\"\xee\x03\n\x13MappingLookupFilter\x12\x14\n\x05local\x18\x01 \x01(\x08R\x05local\x12I\n\x08key_type\x18\x02 \x01(\x0e\x32..opi_api.network.cloud.v1alpha1.MappingKeyTypeR\x07keyType\x12?\n\x04type\x18\x03 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.MappingTypeR\x04type\x12\x45\n\x06ip_key\x18\x04 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.L3MappingKeyH\x00R\x05ipKey\x12G\n\x07mac_key\x18\x05 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.L2MappingKeyH\x00R\x06macKey\x12Q\n\nip_address\x18\x06 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressH\x00R\tipAddress\x12!\n\x0bmac_address\x18\x07 \x01(\x0cH\x00R\nmacAddress\x12\"\n\x0cvpc_name_ref\x18\x08 \x01(\tH\x00R\nvpcNameRefB\x0b\n\tip_or_mac*t\n\x0bMappingType\x12\x1c\n\x18MAPPING_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10MAPPING_TYPE_VPC\x10\x01\x12\x18\n\x14MAPPING_TYPE_SERVICE\x10\x02\x12\x17\n\x13MAPPING_TYPE_LB_VIP\x10\x03*d\n\x0eMappingKeyType\x12 \n\x1cMAPPING_KEY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13MAPPING_KEY_TYPE_L2\x10\x01\x12\x17\n\x13MAPPING_KEY_TYPE_L3\x10\x02\x42m\n\x1eopi_api.network.cloud.v1alpha1B\x0cMappingProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapping_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\014MappingProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_MAPPING']._options = None
  _globals['_MAPPING']._serialized_options = b'\352A<\n&opi_api.network.cloud.v1alpha1/mapping\022\022mappings/{mapping}'
  _globals['_MAPPINGTYPE']._serialized_start=2074
  _globals['_MAPPINGTYPE']._serialized_end=2190
  _globals['_MAPPINGKEYTYPE']._serialized_start=2192
  _globals['_MAPPINGKEYTYPE']._serialized_end=2292
  _globals['_MAPPING']._serialized_start=97
  _globals['_MAPPING']._serialized_end=327
  _globals['_MAPPINGSPEC']._serialized_start=330
  _globals['_MAPPINGSPEC']._serialized_end=935
  _globals['_MAPPINGSTATUS']._serialized_start=938
  _globals['_MAPPINGSTATUS']._serialized_end=1354
  _globals['_L3MAPPINGKEY']._serialized_start=1357
  _globals['_L3MAPPINGKEY']._serialized_end=1486
  _globals['_L2MAPPINGKEY']._serialized_start=1488
  _globals['_L2MAPPINGKEY']._serialized_end=1575
  _globals['_MAPPINGLOOKUPFILTER']._serialized_start=1578
  _globals['_MAPPINGLOOKUPFILTER']._serialized_end=2072
# @@protoc_insertion_point(module_scope)
